@@ -167,12 +167,12 @@ def sigProfilerExtractor(input_type,
                          exome = False, 
                          minimum_signatures=1,
                          maximum_signatures=25,  
-                         nmf_replicates=100, 
+                         nmf_replicates=500, 
                          resample = True, 
                          batch_size=1, 
                          cpu=-1, 
                          gpu=False, 
-                         nmf_init="nndsvd_min", 
+                         nmf_init="random", 
                          precision= "single", 
                          matrix_normalization= "gmm", 
                          seeds= "random", 
@@ -512,6 +512,8 @@ def sigProfilerExtractor(input_type,
             mtypes = ["DBS78"]
         elif mtypes[0] == "83":
             mtypes = ["ID83"]
+        elif mtypes[0] == "48":
+            mtypes = ["CNV48"]
         else:
             mtypes = ["SBS"+mtypes[0]]
         
@@ -663,9 +665,11 @@ def sigProfilerExtractor(input_type,
             m = "DINUC"
         elif m.startswith("ID"):
             m = "ID"
+        elif m.startswith("CNV"):
+            m="CNV"
         
         # Determine the types of mutation which will be needed for exporting and copying the files
-        if not (m=="DINUC" or m.startswith("DBS") or m.startswith("ID")):
+        if not (m=="DINUC" or m.startswith("DBS") or m.startswith("ID") or m.startswith("CNV")):
             
             if m.startswith("SBS"):
                 mutation_type = m
@@ -675,8 +679,10 @@ def sigProfilerExtractor(input_type,
         else:
             if m == "DINUC" or m.startswith("DBS"):
                 mutation_type = "DBS78"
-            elif m== "ID" or m.stratswith("ID"):
+            elif m== "ID" or m.startswith("ID"):
                 mutation_type = "ID83"
+            elif m== "CNV" or m.startswith("CNV"):
+                mutation_type = "CNV48"
                 
        
             
@@ -1013,7 +1019,7 @@ def sigProfilerExtractor(input_type,
             genomes = np.array(genomes)
         
         originalProcessAvg.columns = listOfSignatures    
-        final_signatures = sub.signature_decomposition(processAvg, m, layer_directory2, genome_build=genome_build, add_penalty=add_penalty, remove_penalty=remove_penalty, mutation_context=mutation_context, make_decomposition_plots=make_decomposition_plots, originalProcessAvg=originalProcessAvg)
+        final_signatures = sub.signature_decomposition(processAvg, m, layer_directory2, genome_build=genome_build, add_penalty=0.05, remove_penalty=0.01, mutation_context=mutation_context, make_decomposition_plots=make_decomposition_plots, originalProcessAvg=originalProcessAvg)
         
         # extract the global signatures and new signatures from the final_signatures dictionary
         globalsigs = final_signatures["globalsigs"]
